﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="Controller.cs" company="" />
// <summary>
//   The controller of the Xompare application.
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace Xompare
{
    using System;
    using System.Collections.Generic;

    using Utilities;

    using Xompare.Configuration;

    using System.Linq;

    using Xompare.Helpers;

    /// <summary>
    /// The controller of the Xompare application.
    /// </summary>
    public static class Controller
    {
        static Controller()
        {
            RefreshConfiguration();
        }

        /// <summary>
        /// Version number of the application.
        /// </summary>
        public const string VersionNumber = "0.9.10 Beta";

        /// <summary>
        /// Gets the maintained configuration section of the application.
        /// </summary>
        public static XompareConfigSection ConfigInfo { get; private set; }

        /// <summary>
        /// Gets the enumeration of known extension patterns and behaviors.
        /// </summary>
        public static IEnumerable<KnownExtensionConfigElement> KnownExtensions { get; private set; }

        /// <summary>
        /// Gets or sets the main form of the application.
        /// </summary>
        public static MdiContainer AppMainForm { private get; set; }

        #region CLI parser related

        /// <summary>
        /// Gets or sets the arguments recieved from the CLI.
        /// </summary>
        public static string[] CliArguments { get; set; }

        /// <summary>
        /// Gets or sets the CLI help message for CLI syntax.
        /// </summary>
        public static string CliHelpMessage { get; set; }

        #endregion

        #region Commands

        /// <summary>
        /// Create a new tab with XML files comparator.
        /// </summary>
        /// <param name="getOriginalFilePath">A func to get the original XML file path.</param>
        /// <param name="getTargetFilePath">A func to get the target XML file path.</param>
        public static void CreateFileDiffTab(Func<NameAndLabel> getOriginalFilePath, Func<NameAndLabel> getTargetFilePath)
        {
            AppMainForm.CreateFileDiffTab(getOriginalFilePath, getTargetFilePath);
        }

        #endregion

        /// <summary>
        /// The the recommended default key for a given pattern. Consults also the configuration information.
        /// </summary>
        /// <param name="pattern">A specific file pattern (as appearing in the configuration) or 'null'.</param>
        /// <returns>The recommended default key for the comparison.</returns>
        public static string GetDefaultKey(string pattern = null)
        {
            var requiredExtension = KnownExtensions.FirstOrDefault(extension => extension.Pattern.Equals(pattern));

            return requiredExtension != null && !string.IsNullOrEmpty(requiredExtension.DefaultKey)
                ? requiredExtension.DefaultKey
                : ConfigInfo.DefaultKey;
        }

        /// <summary>
        /// Refresh the configuration information.
        /// </summary>
        public static void RefreshConfiguration()
        {
            ConfigInfo = new AppConfigManager<XompareConfigSection>(XompareConfigSection.SectionName).Configuration;

            KnownExtensions = ConfigInfo.KnownExtensions.Cast<KnownExtensionConfigElement>();
        }
    }
}
