﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace Xompare
{
    using CLAP;

    using Utilities;

    using Xompare.Helpers;

    public partial class MdiContainer : Form
    {
        public MdiContainer()
        {
            InitializeComponent();
        }

        private void aboutToolStripMenuItem_Click(object sender, EventArgs e)
        {
            var aboutForm = new AboutForm();

            aboutForm.ShowDialog();
        }

        private void exitToolStripMenuItem_Click(object sender, EventArgs e)
        {
            Application.Exit();
        }

        private void newFileComparisonToolStripMenuItem_Click(object sender, EventArgs e)
        {
            var fileDialog = new OpenFileDialog { Title = "Choose the original XML file" };

            CreateFileDiffTab(
                () =>
                {
                    fileDialog.ShowDialog();

                    return new NameAndLabel(fileDialog.FileName, null);
                },
                () =>
                {
                    fileDialog.FileName = string.Empty;
                    fileDialog.Title = "Choose the target XML file";
                    fileDialog.ShowDialog();

                    return new NameAndLabel(fileDialog.FileName, null);
                });
        }

        private void closeToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (mdiChildTabs.TabCount > 0)
            {
                mdiChildTabs.TabPages.Remove(mdiChildTabs.SelectedTab);
            }
        }

        #region Helper utilties

        /// <summary>
        /// Create a new tab with XML files comparator.
        /// </summary>
        /// <param name="getOriginalFilePath">A func to get the original XML file path.</param>
        /// <param name="getTargetFilePath">A func to get the target XML file path.</param>
        public void CreateFileDiffTab(Func<NameAndLabel> getOriginalFilePath, Func<NameAndLabel> getTargetFilePath)
        {
            var newComparison = new TabPage("New comparison");
            var comparisonControl = new XmlFilesCompareControl { Dock = DockStyle.Fill };

            comparisonControl.OnComparedFilesChanged +=
                newName => newComparison.Text = newName;

            var originalFilePath = getOriginalFilePath();

            if (!string.IsNullOrEmpty(originalFilePath.Name))
            {
                comparisonControl.OriginalXmlPath = originalFilePath;
                if (!string.IsNullOrEmpty(comparisonControl.OriginalXmlPath.Name) && comparisonControl.OriginalXmlPath.Name.Equals(originalFilePath.Name))
                {
                    var targetFilePath = getTargetFilePath();
                    if (!string.IsNullOrEmpty(targetFilePath.Name))
                    {
                        comparisonControl.TargetXmlPath = targetFilePath;
                        if (!string.IsNullOrEmpty(comparisonControl.TargetXmlPath.Name) && comparisonControl.TargetXmlPath.Name.Equals(targetFilePath.Name))
                        {
                            newComparison.Controls.Add(comparisonControl);
                            mdiChildTabs.TabPages.Add(newComparison);
                            mdiChildTabs.SelectedTab = newComparison;
                        }
                    }
                }
            }
        }

        #endregion

        private void cLISyntaxToolStripMenuItem_Click(object sender, EventArgs e)
        {
            LogUi.LogInfo(Controller.CliHelpMessage);
        }

        private void MdiContainer_Load(object sender, EventArgs e)
        {
            // Create help message for CLI syntax menu:
            Parser.Run<XompareCliParser>(new string[0]);

            // Parse CLI arguments if needed:
            if (Controller.CliArguments.Length > 0)
            {
                if (Parser.RunWinForms<XompareCliParser>(Controller.CliArguments) != 0)
                {
                    Environment.Exit(1);
                }
            }
        }
    }
}
